@@ -21,11 +21,14 @@
 This Minion is meant to control things from accelerometer data.
 '''
 
+import os
 from intercom.minion import Minion
 
-from mpd import MPDClient
-
-mpc = MPDClient()
+#from mpd import MPDClient
+#mpc = MPDClient()
+#mpc.connect("ra.ion", 6600)
+import socket
+s = socket.socket()
 
 
 def mpdControl(measure):
@@ -36,7 +39,8 @@ def mpdControl(measure):
         # command = 'mpc volume {}'.format(int(x2 * 1.5))
         #print('LOL: [{}]'.format(command))
         # os.system(command)
-        mpc.setvol(int(x2 * 1.5))
+        #mpc.setvol(int(x2 * 1.5))
+        s.send('setvol {}\n'.format(int(x2 * 1.5)).encode('utf-8'))
 
 minion = Minion('minion.mpd')
 
@@ -48,5 +52,6 @@ def accelerometer(topic, msg):
 
 
 if __name__ == '__main__':
-    mpc.connect("ra.ion", 6600)
+    #mpc.connect("ra.ion", 6600)
+    s.connect(('ra.ion', 6600))
     minion.run()
